[cfe-commits] r166999 - in /cfe/trunk: include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp

Anna Zaks ganna at apple.com
Mon Oct 29 21:17:19 PDT 2012


Author: zaks
Date: Mon Oct 29 23:17:18 2012
New Revision: 166999

URL: http://llvm.org/viewvc/llvm-project?rev=166999&view=rev
Log:
[analyzer] Rename REGISTER_MAP_WITH_GDM ->REGISTER_MAP_WITH_PROGRAMSTATE

Modified:
    cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h
    cfe/trunk/lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp

Modified: cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h?rev=166999&r1=166998&r2=166999&view=diff
==============================================================================
--- cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h (original)
+++ cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/CheckerContext.h Mon Oct 29 23:17:18 2012
@@ -18,8 +18,8 @@
 #include "clang/StaticAnalyzer/Core/PathSensitive/ExprEngine.h"
 #include "llvm/ADT/ImmutableMap.h"
 
-// Declare an immutable map suitable for placement into program states's GDM.
-#define REGISTER_MAP_WITH_GDM(Map, Key, Value) \
+/// Declare an immutable map suitable for placement into the ProgramState.
+#define REGISTER_MAP_WITH_PROGRAMSTATE(Map, Key, Value) \
   typedef llvm::ImmutableMap<Key, Value> Map; \
   namespace clang { \
   namespace ento { \

Modified: cfe/trunk/lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp?rev=166999&r1=166998&r2=166999&view=diff
==============================================================================
--- cfe/trunk/lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp (original)
+++ cfe/trunk/lib/StaticAnalyzer/Checkers/SimpleStreamChecker.cpp Mon Oct 29 23:17:18 2012
@@ -81,8 +81,8 @@
 } // end anonymous namespace
 
 /// The state of the checker is a map from tracked stream symbols to their
-/// state. Let's store it in the GDM.
-REGISTER_MAP_WITH_GDM(StreamMap, SymbolRef, StreamState)
+/// state. Let's store it in the ProgramState.
+REGISTER_MAP_WITH_PROGRAMSTATE(StreamMap, SymbolRef, StreamState)
 
 void SimpleStreamChecker::checkPostStmt(const CallExpr *Call,
                                         CheckerContext &C) const {





More information about the cfe-commits mailing list